==> haskell-microlens-ghc-0.4.11.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.11.1
id: microlens-ghc-0.4.11.1-B9uxXF1aXHWLQD0xUH9ve5
key: microlens-ghc-0.4.11.1-B9uxXF1aXHWLQD0xUH9ve5
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: 8a6ec8d4bca0bd691661e0e5d7cb05b2
exposed: True
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-ghc-0.4.11.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-ghc-0.4.11.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-ghc-0.4.11.1
hs-libraries: HSmicrolens-ghc-0.4.11.1-B9uxXF1aXHWLQD0xUH9ve5
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    microlens-0.4.11.1-5dh821ORebgAorhvJor7TN transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.11.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.11.1
id: microlens-ghc-0.4.11.1-8gcYrT9eyRBCx0ooiq6T3c
key: microlens-ghc-0.4.11.1-8gcYrT9eyRBCx0ooiq6T3c
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: 009313b1d2e6f1e70c8c5d154818107b
exposed: True
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-ghc-0.4.11.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-ghc-0.4.11.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-ghc-0.4.11.1
hs-libraries: HSmicrolens-ghc-0.4.11.1-8gcYrT9eyRBCx0ooiq6T3c
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
